﻿import es
import langlib
import playerlib
import popuplib

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2011/language/"

texts = langlib.Strings(lang_dir + "modules/match/popup_match_names.ini")
text_score = langlib.Strings(lang_dir + "modules/match/popup_match_score.ini")
messages = langlib.Strings(lang_dir + "modules/match/messages_match_names.ini")

popup = popuplib.create("sm_popup_admin_match_names")

settings = ["name_t", "name_ct", "short_name_t", "short_name_ct"]

# ******************** Load ********************
def load():
	load_variables()

	create_popup()

	es.addons.registerSayFilter(filter)

# ******************** Load variables ********************
def load_variables():
	for item in settings:
		es.set("sm_match_%s" % (item), es.ServerVar("sm_match_default_%s" % (item)))

# ******************** Create popup ********************
def create_popup():
	common = langlib.Strings(lang_dir + "popup_common.ini")

	popup.addline("SOCCER MOD %s" % (texts("title")))
	popup.addline(" ")

	for i in range(0, len(settings)):
		popup.addline("->%s. %s: %s" % (i + 1, texts(settings[i]), es.ServerVar("sm_match_%s" % (settings[i]))))

	popup.addline("->5. %s" % (texts("reset")))
	popup.addline(" ")
	popup.addline("->9. %s" % (common("back")))
	popup.addline(" ")
	popup.addline("->0. %s" % (common("close")))

	for i in range(1, 5):
		popup.select(i, change_name)

	popup.select(5, reset_names)

	for i in range(6, 9):
		popup.submenu(i, "sm_popup_admin_match_names")

	popup.submenu(9, "sm_popup_admin_match")

# ******************** Popup choice ********************
def change_name(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "match_%s" % (settings[choice - 1]))
	es.tell(userid, "#green", messages("type_%s" % (settings[choice - 1]), tokens, player.get("lang")))

def reset_names(userid, choice, popupid):
	name = es.ServerVar("sm_match_default_name_t")
	popup.modline(3, "->1. %s: %s" % (texts("name_t"), name))
	es.set("sm_match_name_t", name)

	tokens = {}
	tokens["team"] = name
	popuplib.find("sm_popup_admin_match_score").modline(3, "->1. %s" % (text_score("add", tokens)))

	tokens["team"] = name
	popuplib.find("sm_popup_admin_match_score").modline(4, "->2. %s" % (text_score("remove", tokens)))

	name = es.ServerVar("sm_match_default_name_ct")
	popup.modline(4, "->2. %s: %s" % (texts("name_ct"), name))
	es.set("sm_match_name_ct", name)

	tokens["team"] = name
	popuplib.find("sm_popup_admin_match_score").modline(5, "->3. %s" % (text_score("add", tokens)))

	tokens["team"] = name
	popuplib.find("sm_popup_admin_match_score").modline(6, "->4. %s" % (text_score("remove", tokens)))

	name = es.ServerVar("sm_match_default_short_name_t")
	popup.modline(5, "->3. %s: %s" % (texts("short_name_t"), name))
	es.set("sm_match_short_name_t", name)

	name = es.ServerVar("sm_match_default_short_name_ct")
	popup.modline(6, "->4. %s: %s" % (texts("short_name_ct"), name))
	es.set("sm_match_short_name_ct", name)

	tokens["name"] = es.getplayername(userid)
	lang_msg("reset", tokens)

	popuplib.send("sm_popup_admin_match_names", userid)

# ******************** Events ********************
def filter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)
	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		text = text.strip('"')
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		if type == "match_name_t":
			set_value(text, userid, 25, "name_t", 1)
			return (0, None, 0)
		elif type == "match_name_ct":
			set_value(text, userid, 25, "name_ct", 2)
			return (0, None, 0)
		elif type == "match_short_name_t":
			set_value(text, userid, 5, "short_name_t", 3)
			return (0, None, 0)
		elif type == "match_short_name_ct":
			set_value(text, userid, 5, "short_name_ct", 4)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Functions ********************
def lang_msg(text, tokens):
	for player in playerlib.getPlayerList("#human"):
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def set_value(text, userid, max, type, number):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if text != "!cancel":
		if len(text) <= max:
			es.set("sm_match_%s" % (type), text)

			popup.modline((number + 2), "->%s. %s: %s" % (number, texts(type), text))

			tokens = {}
			tokens["team"] = es.ServerVar("sm_match_%s" % (type))

			if number == 1:
				popuplib.find("sm_popup_admin_match_score").modline(3, "->1. %s" % (text_score("add", tokens)))
				popuplib.find("sm_popup_admin_match_score").modline(4, "->2. %s" % (text_score("remove", tokens)))

			elif number == 2:
				popuplib.find("sm_popup_admin_match_score").modline(5, "->3. %s" % (text_score("add", tokens)))
				popuplib.find("sm_popup_admin_match_score").modline(6, "->4. %s" % (text_score("remove", tokens)))

			tokens["name"] = player.name
			tokens["value"] = text
			lang_msg("set_%s" % (type), tokens)

			clear_key(userid, player.steamid)
		else:
			tokens["number"] = max
			es.tell(userid, "#green", messages("to_long", tokens, player.get("lang")))
	else:
		clear_key(userid, player.steamid)

def clear_key(userid, steamid):
	es.keydelete("sm_keygroup_set", steamid)

	popuplib.send("sm_popup_admin_match_names", userid)

# ******************** Unload ********************
def unload():
	es.addons.unregisterSayFilter(filter)

	popuplib.delete("sm_popup_admin_match_names")